@@ -71,7 +71,8 @@ class CanonicalException(Exception):
     def set_backoff(self,
         ttl: int,
         expires: int,
-        attempts: int
+        attempts: int,
+        timestamp: int
     ) -> None:
         """Set a backoff (cooldown) period that indicating how
         long the caller wait before retrying the request that
@@ -80,7 +81,8 @@ class CanonicalException(Exception):
         self.backoff = {
             'ttl': ttl,
             'expires': expires,
-            'attempts': attempts
+            'attempts': attempts,
+            'timestamp': timestamp
         }
 
     def __str__(self) -> str:
